==> dev-plugin-android-7.1.0-beta1-sources.jar: com/zoyi/channel/plugin/android/store/binder/Binder3.java <==
package com.zoyi.channel.plugin.android.store.binder;

import android.support.annotation.Nullable;
import com.zoyi.channel.plugin.android.store.state.BaseState;
import com.zoyi.rx.Subscription;
import com.zoyi.rx.functions.Action3;

public class Binder3<E, F, G> extends Binder {

  private BaseState<E> state1;
  private BaseState<F> state2;
  private BaseState<G> state3;

  @Nullable
  private Subscription subscription1;
  @Nullable
  private Subscription subscription2;
  @Nullable
  private Subscription subscription3;

  public Binder3(BaseState<E> state1, BaseState<F> state2, BaseState<G> state3) {
    this.state1 = state1;
    this.state2 = state2;
    this.state3 = state3;
  }

  public Binder3 bind(Action3<E, F, G> action3) {
    this.subscription1 = this.state1.attach(e -> action3.call(e, state2.get(), state3.get()));
    this.subscription2 = this.state2.attach(f -> action3.call(state1.get(), f, state3.get()));
    this.subscription3 = this.state3.attach(g -> action3.call(state1.get(), state2.get(), g));

    action3.call(state1.get(), state2.get(), state3.get());

    return this;
  }

  @Override
  public void unbind() {
    if (subscription1 != null && !subscription1.isUnsubscribed()) {
      subscription1.unsubscribe();
    }
    if (subscription2 != null && !subscription2.isUnsubscribed()) {
      subscription2.unsubscribe();
    }
    if (subscription3 != null && !subscription3.isUnsubscribed()) {
      subscription3.unsubscribe();
    }
    subscription1 = null;
    subscription2 = null;
    subscription3 = null;
  }
}

==> dev-plugin-android-9.0.0+beta1-sources.jar: com/zoyi/channel/plugin/android/store/binder/Binder3.java <==
package com.zoyi.channel.plugin.android.store.binder;

import androidx.annotation.Nullable;

import com.zoyi.channel.plugin.android.bind.Binder;
import com.zoyi.channel.plugin.android.store.state.BaseState;
import com.zoyi.rx.Subscription;
import com.zoyi.rx.functions.Action3;

public class Binder3<E, F, G> extends Binder {

  private BaseState<E> state1;
  private BaseState<F> state2;
  private BaseState<G> state3;

  @Nullable
  private Subscription subscription1;
  @Nullable
  private Subscription subscription2;
  @Nullable
  private Subscription subscription3;

  public Binder3(BaseState<E> state1, BaseState<F> state2, BaseState<G> state3) {
    this.state1 = state1;
    this.state2 = state2;
    this.state3 = state3;
  }

  public Binder3 bind(Action3<E, F, G> action3) {
    this.subscription1 = this.state1.attach(e -> action3.call(e, state2.get(), state3.get()));
    this.subscription2 = this.state2.attach(f -> action3.call(state1.get(), f, state3.get()));
    this.subscription3 = this.state3.attach(g -> action3.call(state1.get(), state2.get(), g));

    action3.call(state1.get(), state2.get(), state3.get());

    return this;
  }

  @Override
  public void unbind() {
    if (subscription1 != null && !subscription1.isUnsubscribed()) {
      subscription1.unsubscribe();
    }
    if (subscription2 != null && !subscription2.isUnsubscribed()) {
      subscription2.unsubscribe();
    }
    if (subscription3 != null && !subscription3.isUnsubscribed()) {
      subscription3.unsubscribe();
    }
    subscription1 = null;
    subscription2 = null;
    subscription3 = null;
  }
}
